An experiment studying the interaction between visual versus perception and visual versus verbal responses.
vizverbA data frame with 80 observations on the following 5 variables.
Subject identifying number (s1 to s20)
Describe a diagram (visual) or a sentence (verbal)
Point response (visual) or say response (verbal)
Response time (in seconds)
Subjects carried out two kinds of tasks. One task was visual (describing a diagram), and the other was classed as verbal (reading and describing a sentence sentences). They reported the results either by pointing (a "visual" response), or speaking (a verbal response). Time to complete each task was recorded in seconds.